@@ -5,22 +5,27 @@
 #'
 #'This package contains function to compute Bayes factors for a number of 
 #'research designs and hypotheses, including t tests, ANOVA, and linear 
-#'regression.
+#'regression, and contingency tables.
 #'
 #'\tabular{ll}{ Package: \tab BayesFactor\cr Type: \tab Package\cr Version: \tab
-#'0.9.8\cr Date: \tab 2014-3-22\cr License: \tab GPL 2.0\cr LazyLoad: \tab 
+#'0.9.9\cr Date: \tab 2014-10-22\cr License: \tab GPL 2.0\cr LazyLoad: \tab 
 #'yes\cr } The following methods are currently implemented, with more to follow:
 #'
-#'Linear regression: \code{\link{regressionBF}} \code{\link{lmBF}}, 
+#'general linear models (including linear mixed effects models): \code{\link{generalTestBF}}, \code{\link{lmBF}}
+#'
+#'linear regression: \code{\link{regressionBF}}, \code{\link{lmBF}}, 
 #'\code{\link{linearReg.R2stat}};
 #'
-#'t test: \code{\link{ttestBF}}, \code{\link{ttest.tstat}};
+#'t tests: \code{\link{ttestBF}}, \code{\link{ttest.tstat}};
 #'
-#'ANOVA: \code{\link{anovaBF}}, \code{\link{lmBF}}, 
-#'\code{\link{oneWayAOV.Fstat}};
+#'meta-analytic t tests: \code{\link{meta.ttestBF}}
+#'
+#'ANOVA: \code{\link{anovaBF}}, \code{\link{lmBF}}, \code{\link{oneWayAOV.Fstat}};
 #'
 #'contingency tables: \code{\link{contingencyTableBF}};
 #'
+#'single proportions: \code{\link{proportionBF}};
+#'
 #'Other useful functions: \code{\link{posterior}}, for sampling from posterior 
 #'distributions; \code{\link{recompute}}, for re-estimating a Bayes factor or 
 #'posterior distribution; \code{\link{compare}}, to compare two model
@@ -30,7 +35,7 @@
 #'@name BayesFactor-package
 #'@aliases BayesFactor-package BayesFactor
 #'@docType package
-#'@author Richard D. Morey and Jeffrey N. Rouder
+#'@author Richard D. Morey and Jeffrey N. Rouder (with contributions from Tahira Jamil)
 #'  
 #'  Maintainer: Richard D. Morey <richarddmorey@@gmail.com>
 #'@seealso \code{\link[BAS:BAS-package]{BAS}}
@@ -95,5 +100,31 @@ NULL
 #'
 NULL
 
-
-
+#'Hraba and Grant (1970) children's doll preference data
+#'
+#'Hraba and Grant (1970) describe a replication of Clark and Clark (1947) in which
+#'black and white children from Lincoln, Nebraska were shown dolls that were either black
+#'or white. They were then asked a series of questions, including "Give me the doll that is 
+#'a nice doll." This data set contains the frequency of children giving the same-race or different race doll in
+#'response to this question.
+#'@name raceDolls
+#'@docType data
+#'@format A matrix with 2 rows and 2 columns. Rows give doll preference; colums give the 
+#'race of the child.
+#'@source Hraba, J. and Grant, G. (1970). Black is Beautiful: A reexamination of 
+#'racial preference and identification. Journal of Personality and Social Psychology, 16, 398-402.
+#'
+#'@keywords datasets
+#'@examples
+#'
+#'data(raceDolls)
+#'
+#'## chi-square test
+#'## Barely significant with continuity correction
+#'chisq.test(raceDolls)
+#'
+#'## Bayes factor test (assuming independent binomial sampling plan)
+#'## Very little evidence for the alternative of lack of independence
+#'bf = contingencyTableBF(raceDolls, sampleType = "indepMulti", fixedMargin = "cols")
+#'bf
+NULL
