@@ -172,7 +172,7 @@ anovaBF <-
     }
     
     if(multicore){
-      message("Progress bars and callbacks are suppressed when running multicore.")
+      message("Note: Progress bars and callbacks are suppressed when running multicore.")
       if(!require(doMC, quietly = TRUE)){
         stop("Required package (doMC) missing for multicore functionality.")
       } 
